function RO = wgs_rep(PRN,date,t,source_file)
%
% vytvoil Lubo Tlskal - mlokin@centrum.cz
%
 % eph=xyzwgs( int PRN, int t, string source_file)
  %
  % PURPOSE    :  VYHLEDA EFEMERIDY NEJBLIZSI ZADANEMU CASU
  %               V PRISLUSNEM SOUBORU FORMATU RINEX A SPOCTE SOURADNICE
  %               DRUZICE V SYSTEMU WGS84  
  %               
  %
  % PARAMETERS :
  %         IN :  xyzwgs: ( int id,int t,string source_file)
  %                          id (E.G. 10)                  
  %                          t  (E.G. 49244 CAS V SEC OD PULNOCI)        
  %                          source_file(E.G. GOPE0810[1].txt)                      
  %        OUT :  RO = [x;y;z]                    
  %--------------------------------------------------------------------

%-----------------------------------------------------------------------------------
%konstanty

omega_e = 7292115.1467E-11; %s-1
GM      = 398.6005E12;       %m3s-2
%-----------------------------------------------------------------------------------
%nacteni aktualnich efemerid

EF = ephemeris(PRN,date,t,source_file);
%-----------------------------------------------------------------------------------
%efemeridy
datum = [EF(1,3),EF(1,4)];
dt = EF(2,2);
ddt =EF(2,3);
dddt= EF(2,4);
Mo = EF(3,4);
sqrt_a = EF(4,4);
to = EF(2,1);
dn =  EF(3,3);
Lo =EF(5,3);
omega_0 = EF(6,3);
io = EF(6,1);
TOE = EF(5,1);
Cuc = EF(4,1);
Cus = EF(4,3);
Crc = EF(6,2);
Crs = EF(3,2);
Cic = EF(5,2);
Cis = EF(5,4);
OMEGA =EF(6,4);
e = EF(4,2);
di = EF(7,1);
io= EF(6,1);

%oprava hodin druzice
Cclock =dt+ddt*(t-to)+dddt*(t-to)^2; 

%Stredni anomalie M
M = Mo+(sqrt(GM)/sqrt_a^3+dn)*(t-to);

%delka L vystupneho uzlu  v terestrickem systemu  (uhel rotace okolo z)
L = Lo+(OMEGA-omega_e)*(t-to)-omega_e*TOE;
%Excentricka anomalie E

E_old = M;
E = 1;

while (abs(E-E_old)>1e-20)
    E_old = E;
    E = M+e*sin(E_old);
end


%prava anomalie uhel , ktery svira pruvodic se smerem do perigea
v =2*atan2(sqrt(1+e)*tan(E/2),sqrt(1-e));
%argument sirky+prava anomalie
u = v+omega_0+Cuc*cos(2*v+2*omega_0)+Cus*sin(2*v+2*omega_0);
% argument sirky
omega = omega_0+Cuc*cos(2*u)+Cus*sin(2*u);
%sklon roviny drahy
i = io + Cic*cos(2*u)+Cis*sin(2*u)+di*(t-to);
%delka pruvodice
r = sqrt_a^2*(1-e*cos(E))+Crc*cos(2*u)+Crs*sin(2*u);
%vektor pruvodice v rovine drahy
vec_r =[r*cos(v);r*sin(v);0];
%vektor pruvodice v rovnikove soustave
vec_ro = rz(-OMEGA)*rx(-i)*rz(-omega)*vec_r; 
%vektor pruvodice v soustave spojene se zemi (WGS84)
RO = rz(-L)*rx(-i)*rz(-omega)*vec_r;

%------------------------------------------------------------------------------------

tex=fopen('wgsreport.txt','w+');

fprintf(tex,'\tVypocet souradnic druzice v WGS84\n');
fprintf(tex,'\t====================================\n\n');
fprintf(tex,'\Vysilane efemeridy pouzite k vypoctu\n');
fprintf(tex,'PRN = %2.0f   datum  %2.0f %2.0f   cas gps to = %6.1f sec \n',EF(1,1),datum,to);
fprintf(tex,'---------------------------------------------------------------------\n\n');
fprintf(tex,'oprava hodin druzice =               dt = %15.14e s\n',Cclock);
fprintf(tex,'stredni anomalie v case to           Mo = %15.14e rad\n',Mo);
fprintf(tex,'oprava stredniho pohybu              dn = %15.14e rad s-1 \n',dn);
fprintf(tex,'odmocnina s delky velke poloosy  sqrt_a = %15.14e m \n',sqrt_a);
fprintf(tex,'delka vystupneho uzlu v case to      Lo = %15.14e rad\n',Lo);
fprintf(tex,'argument perignea v case to     omega_0 = %15.14e rad\n',omega_0);
fprintf(tex,'sklon drahy pro epochu  to           io = %15.14e rad\n',io);
fprintf(tex,'argument perignea pro epochu to      wo = %15.14e rad\n',omega_0);
fprintf(tex,'drift vystupneho uzlu                OM = %15.14e rad s-1\n',OMEGA);
fprintf(tex,'drift sklonu drahy                   di = %15.14e rad s-1\n',di);
fprintf(tex,'---------------------------------------------------------------------\n\n');

fprintf(tex,'prava anomalie                        v = %15.14e rad \n',v);
fprintf(tex,'argument sirky+prava anomalie         u = %15.14e rad \n',u);
fprintf(tex,'argument sirky            omega = %15.14e rad s-1 \n',omega);
fprintf(tex,'sklon roviny drahy                    i = %15.14e rad \n',i);
fprintf(tex,'delka pruvodice                       r = %15.14e m \n',r);
fprintf(tex,'vektor pruvodice v rovine drahy\n')
fprintf(tex,'       R =[%15.14e %15.14e %15.14e] m \n\n',vec_r);
fprintf(tex,'vektor pruvodice v soustave spojene se zemi (WGS84)\n');      
fprintf(tex,'    Rwgs =[%15.14e %15.14e %15.14e] m \n',RO);
fprintf(tex,'---------------------------------------------------------------------\n\n');
fclose(tex);